@@ -24,6 +24,9 @@
 #endif
 #include "logger.hh"
 #include "version.hh"
+#include "dnsbackend.hh"
+
+#include <boost/algorithm/string/join.hpp>
 
 static ProductType productType;
 
@@ -67,7 +70,7 @@ string productTypeApiType() {
 
 void showProductVersion()
 {
-  g_log<<Logger::Warning<<productName()<<" "<< VERSION << " (C) 2001-2022 "
+  g_log<<Logger::Warning<<productName()<<" "<< VERSION << " (C) "
     "PowerDNS.COM BV" << endl;
   g_log<<Logger::Warning<<"Using "<<(sizeof(unsigned long)*8)<<"-bits mode. "
     "Built using " << compilerVersion()
@@ -138,13 +141,24 @@ void showBuildConfiguration()
 #ifdef HAVE_LIBCURL
     "curl " <<
 #endif
+#ifdef HAVE_DNS_OVER_TLS
+    "DoT " <<
+#endif
+#ifdef HAVE_EVP_PKEY_CTX_SET1_SCRYPT_SALT
+    "scrypt " <<
+#endif
+#ifdef ENABLE_GSS_TSIG
+    "gss-tsig " <<
+#endif
 #ifdef VERBOSELOG
     "verboselog" <<
 #endif
     endl;
 #ifdef PDNS_MODULES
   // Auth only
-  g_log<<Logger::Warning<<"Built-in modules: "<<PDNS_MODULES<<endl;
+  g_log << Logger::Warning << "Built-in modules: " << PDNS_MODULES << endl;
+  const auto& modules = BackendMakers().getModules();
+  g_log << Logger::Warning << "Loaded modules: " << boost::join(modules, " ") << endl;
 #endif
 #ifdef PDNS_CONFIG_ARGS
 #define double_escape(s) #s
